# coding: utf-8

"""
    FINBOURNE Access Management API

    FINBOURNE Technology  # noqa: E501

    Contact: info@finbourne.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


import json
import pprint
import re  # noqa: F401
from aenum import Enum, no_arg

from typing import List, Dict, Optional, Any, Union, TYPE_CHECKING
from typing_extensions import Annotated
from pydantic.v1 import BaseModel, StrictStr, StrictInt, StrictBool, StrictFloat, StrictBytes, Field, validator, ValidationError, conlist, constr
from datetime import datetime


class TextOperator(str, Enum):
    """
    TextOperator
    """

    """
    allowed enum values
    """
    UNDEFINED = 'Undefined'
    EQUALSCASESENSITIVE = 'EqualsCaseSensitive'
    EQUALSCASEINSENSITIVE = 'EqualsCaseInsensitive'
    NOTEQUALSCASESENSITIVE = 'NotEqualsCaseSensitive'
    NOTEQUALSCASEINSENSITIVE = 'NotEqualsCaseInsensitive'
    CONTAINSCASESENSITIVE = 'ContainsCaseSensitive'
    NOTPRESENTORNOTCONTAINSCASESENSITIVE = 'NotPresentOrNotContainsCaseSensitive'
    NOTPRESENT = 'NotPresent'
    INCASEINSENSITIVE = 'InCaseInsensitive'

    @classmethod
    def from_json(cls, json_str: str) -> TextOperator:
        """Create an instance of TextOperator from a JSON string"""
        return TextOperator(json.loads(json_str))
